==> common-api-0.0.98-sources.jar: io/aether/api/common/SodiumChacha20Poly1305.java <==
package io.aether.api.common;
import java.net.URI;
import java.net.URISyntaxException;
import io.aether.net.fastMeta.FastMetaType;
import java.util.UUID;
import java.util.Date;
import io.aether.net.fastMeta.BytesConverter;
import java.io.Closeable;
import io.aether.net.fastMeta.*;
import io.aether.utils.dataio.DataIn;
import io.aether.utils.dataio.DataOut;
import io.aether.utils.dataio.DataInOutStatic;
import io.aether.utils.dataio.DataInOut;
import it.unimi.dsi.fastutil.objects.ObjectSet;
import it.unimi.dsi.fastutil.bytes.ByteSet;
import it.unimi.dsi.fastutil.doubles.DoubleSet;
import it.unimi.dsi.fastutil.floats.FloatSet;
import it.unimi.dsi.fastutil.ints.IntSet;
import it.unimi.dsi.fastutil.longs.LongSet;
import it.unimi.dsi.fastutil.shorts.ShortSet;
import io.aether.utils.interfaces.AConsumer;
import io.aether.utils.futures.AFuture;
import io.aether.utils.futures.ARFuture;
import java.lang.annotation.*;
import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;
import java.util.*;
public class SodiumChacha20Poly1305 extends KeySymmetric implements io.aether.utils.ToString  {
    @Override public int getAetherTypeId() {
        return 6;
        
    }
    public static final FastMetaType<SodiumChacha20Poly1305> META_BODY = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_32, SodiumChacha20Poly1305 obj_33, DataOut out_34) {
            if(obj_33.data.length!=32) throw new java.lang.IllegalArgumentException("Array length is bad for obj_33.data=="+obj_33.data.length+" but must be 32");
            out_34.write(obj_33.data);
            
        }
        @Override public SodiumChacha20Poly1305 deserialize(FastFutureContext serializeContextVar_32, DataIn in_35) {
            byte[] data_36;
            var arraySize_37=32;
            data_36=new byte[arraySize_37];
            in_35.read(data_36);
            return new SodiumChacha20Poly1305(data_36);
            
        }
        
    };
    public static final FastMetaType<SodiumChacha20Poly1305> META = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_38, SodiumChacha20Poly1305 obj_39, DataOut out_40) {
            SodiumChacha20Poly1305.META_BODY.serialize(serializeContextVar_38, obj_39, out_40);
            
        }
        @Override public SodiumChacha20Poly1305 deserialize(FastFutureContext serializeContextVar_38, DataIn in_41) {
            return SodiumChacha20Poly1305.META_BODY.deserialize(serializeContextVar_38, in_41);
            
        }
        
    };
    protected final @L(32) byte[] data;
    public SodiumChacha20Poly1305(@L(32) byte[] data)  {
        if (data == null)  {
            throw new java.lang.NullPointerException("Field 'data' cannot be null.");
            
        }
        if (data.length != 32)  {
            throw new java.lang.IllegalArgumentException("Array length for field 'data' must be 32 but was " + data.length);
            
        }
        this.data = data;
        
    }
    public @L(32) byte[] getData()  {
        return this.data;
        
    }
    public boolean dataContains(byte el)  {
        return ByteSet.of(this.data).contains(el);
        
    }
    @Override public boolean equals(Object o)  {
        if (this == o) return true;
        if (o == null || !(o instanceof SodiumChacha20Poly1305)) return false;
        SodiumChacha20Poly1305 that = (SodiumChacha20Poly1305) o;
        return java.util.Arrays.equals(this.data, that.data);
        
    }
    @Override public int hashCode()  {
        return java.util.Objects.hash(java.util.Arrays.hashCode(this.data));
        
    }
    @Override public void toString(io.aether.utils.AString sb)  {
        sb.add("SodiumChacha20Poly1305(");
        sb.add("data:");
        sb.add(this.data);
        sb.add(')');
        
    }
    
}

==> common-api-0.0.100-sources.jar: io/aether/api/common/SodiumChacha20Poly1305.java <==
package io.aether.api.common;
import java.net.URI;
import java.net.URISyntaxException;
import io.aether.net.fastMeta.FastMetaType;
import java.util.UUID;
import java.util.Date;
import io.aether.net.fastMeta.BytesConverter;
import java.io.Closeable;
import io.aether.net.fastMeta.*;
import io.aether.utils.dataio.DataIn;
import io.aether.utils.dataio.DataOut;
import io.aether.utils.dataio.DataInOutStatic;
import io.aether.utils.dataio.DataInOut;
import it.unimi.dsi.fastutil.objects.ObjectSet;
import it.unimi.dsi.fastutil.bytes.ByteSet;
import it.unimi.dsi.fastutil.doubles.DoubleSet;
import it.unimi.dsi.fastutil.floats.FloatSet;
import it.unimi.dsi.fastutil.ints.IntSet;
import it.unimi.dsi.fastutil.longs.LongSet;
import it.unimi.dsi.fastutil.shorts.ShortSet;
import io.aether.utils.interfaces.AConsumer;
import io.aether.utils.futures.AFuture;
import io.aether.utils.futures.ARFuture;
import java.lang.annotation.*;
import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;
import java.util.*;
public class SodiumChacha20Poly1305 extends KeySymmetric implements io.aether.utils.ToString  {
    @Override public int getAetherTypeId() {
        return 6;
        
    }
    public static final FastMetaType<SodiumChacha20Poly1305> META_BODY = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_32, SodiumChacha20Poly1305 obj_33, DataOut out_34) {
            if(obj_33.data.length!=32) throw new java.lang.IllegalArgumentException("Array length is bad for obj_33.data=="+obj_33.data.length+" but must be 32");
            out_34.write(obj_33.data);
            
        }
        @Override public SodiumChacha20Poly1305 deserialize(FastFutureContext serializeContextVar_32, DataIn in_35) {
            byte[] data_36;
            var arraySize_37=32;
            data_36=new byte[arraySize_37];
            in_35.read(data_36);
            return new SodiumChacha20Poly1305(data_36);
            
        }
        
    };
    public static final FastMetaType<SodiumChacha20Poly1305> META = new FastMetaType<>() {
        @Override public void serialize(FastFutureContext serializeContextVar_38, SodiumChacha20Poly1305 obj_39, DataOut out_40) {
            SodiumChacha20Poly1305.META_BODY.serialize(serializeContextVar_38, obj_39, out_40);
            
        }
        @Override public SodiumChacha20Poly1305 deserialize(FastFutureContext serializeContextVar_38, DataIn in_41) {
            return SodiumChacha20Poly1305.META_BODY.deserialize(serializeContextVar_38, in_41);
            
        }
        
    };
    protected final byte[] data;
    public SodiumChacha20Poly1305(byte[] data)  {
        if (data == null)  {
            throw new java.lang.NullPointerException("Field 'data' cannot be null.");
            
        }
        if (data.length != 32)  {
            throw new java.lang.IllegalArgumentException("Array length for field 'data' must be 32 but was " + data.length);
            
        }
        this.data = data;
        
    }
    public byte[] getData()  {
        return this.data;
        
    }
    public boolean dataContains(byte el)  {
        return ByteSet.of(this.data).contains(el);
        
    }
    @Override public boolean equals(Object o)  {
        if (this == o) return true;
        if (o == null || !(o instanceof SodiumChacha20Poly1305)) return false;
        SodiumChacha20Poly1305 that = (SodiumChacha20Poly1305) o;
        return java.util.Arrays.equals(this.data, that.data);
        
    }
    @Override public int hashCode()  {
        return java.util.Objects.hash(java.util.Arrays.hashCode(this.data));
        
    }
    @Override public String toString()  {
        return toString2();
        
    }
    @Override public void toString(io.aether.utils.AString sb)  {
        sb.add("SodiumChacha20Poly1305(");
        sb.add("data:");
        sb.add(this.data);
        sb.add(')');
        
    }
    
}
